<?php 

/**
* Plugin Name: Форум
* Version: 1.0.4
* Author: alex-borisi
* AuthorURI: https://andryushkin.ru
* Description: Простой форум для вашего сайта
*/ 

define('DS_FORUM', preg_replace('/.*\//', '', dirname(__FILE__))); 

require 'includes/inc.functions.php';
require 'includes/inc.DB_Forum_Topics.php';
require 'includes/inc.Widget_Forum.php';

/**
* Проверка таблиц форума
*/ 
add_event('ds_plugin_' . DS_FORUM . '_activation', 'ds_forum_activate'); 
function ds_forum_activate($plugin) {
	require 'includes/inc.activate.php';
}

add_filter('ds_comment_table', 'set_comments_forum', 10, 3); 
function set_comments_forum($table_name, $object_type, $object_id = 0) 
{
	if ($object_type == 'forum') {
		$table_name = 'forum_comments'; 
	}
	return $table_name; 
}

/**
* Обновляем время поднятия темы
*/ 
add_event('ds_comment_send', 'ds_forum_comment_send', 10, 2); 
function ds_forum_comment_send($comment_id, $object, $object_id) 
{
	if ($object == 'forum') {
		$topic = get_forum_topic($object_id);

		if (isset($topic['id'])) {
			db::update('forum_topics', array(
				'uptime' => time(), 
			), array(
				'id' => $object_id,
			)); 
		}
	}
}

add_event('ds_init', 'ds_forum_init'); 
function ds_forum_init() 
{
	ds_rewrite_rule('forum\/?', 'ds_forum_parse_request'); 
	ds_rewrite_rule('forum\/([A-z0-9\-\_]+)\/?', 'ds_forum_parse_request', 'forum=$1'); 
	ds_rewrite_rule('forum\/([A-z0-9\-\_]+)\/([0-9]+)\/?', 'ds_forum_parse_request', 'forum=$1&topic_id=$2'); 
	ds_rewrite_rule('forum\/([A-z0-9\-\_]+)\/([0-9]+)\/([A-z])\/?', 'ds_forum_parse_request', 'forum=$1&topic_id=$2&action=$3'); 
}

function ds_forum_parse_request() 
{
	global $set, $user; 

	$plug = basename(dirname(__FILE__)); 
	$get = ds_get('route_request'); 
	$forum_id = (isset($get['forum']) ? $get['forum'] : 0); 
	$topic_id = (isset($get['topic_id']) ? $get['topic_id'] : 0); 
	$action = (isset($_GET['action']) ? $_GET['action'] : ''); 

	if ($forum_id !== 0) {
		$forum = get_forum($forum_id); 

		if (isset($forum['id'])) {
			$forum_id = (int) $forum['id']; 
		} else {
			p404();
		}
	}

	if ($topic_id !== 0) {
		$topic = get_forum_topic($topic_id); 
	}

	$permalinks = array(
		'forum' => get_site_url('/forum/%slug%/'), 
		'topic' => get_site_url('/forum/%slug%/%topic_id%/'), 
	); 

	if ($action == 'remove') {
		require dirname(__FILE__) . '/template/topic.remove.php'; 
	} elseif ($action == 'create') {
		require dirname(__FILE__) . '/template/topic.create.php'; 
	} elseif ($action == 'edit') {
		require dirname(__FILE__) . '/template/topic.edit.php'; 
	} elseif (isset($topic['id'])) {
		require dirname(__FILE__) . '/template/topic.php'; 
	} else {
		require dirname(__FILE__) . '/template/forum.php'; 
	}

	die(); 
}

/**
* Админка форума
*/ 

add_event('ds_admin_init', 'ds_forum_admin_init'); 
function ds_forum_admin_init() {
	$plug = basename(dirname(__FILE__)); 
    add_menu_admin(__p('Форум', $plug), $plug, 'adm_set_sys', 'fa-comments', 80, __p('Форум', $plug), 'ds_forum_admin_page'); 

    if (isset($_GET['admin']) && $_GET['admin'] == $plug) {
		$forum_id = (isset($_GET['forum_id']) ? $_GET['forum_id'] : 0); 
		$action = (isset($_GET['action']) ? $_GET['action'] : 'list'); 

		$forum = array(); 
		if ($forum_id) {
			$forum = get_forum($forum_id); 
		}

		if ($action == 'list') {
		    add_event('ds_admin_title_action', function($links = array()) {
		    	$forum_id = (isset($_GET['forum_id']) ? $_GET['forum_id'] : 0); 
		    	$plug = basename(dirname(__FILE__)); 

		        $links['add'] = array(
		            'title' => __p('Добавить раздел', $plug), 
		            'url'   => get_admin_url($plug, array(
					    'forum_id' => $forum_id, 
					    'action' => 'create', 
		            )), 
		        ); 
		        
		        return $links; 
		    });   
		}

		require dirname(__FILE__) . '/includes/admin.action.php'; 
    }
}

function ds_forum_admin_page() {
	$plug = basename(dirname(__FILE__)); 

	$forum_id = (isset($_GET['forum_id']) ? (int) $_GET['forum_id'] : 0); 
	$action = (isset($_GET['action']) ? $_GET['action'] : 'list'); 

	$forum = array(); 
	if ($forum_id) {
		$forum = get_forum($forum_id); 
	}

	if ($action == 'remove') {
		require dirname(__FILE__) . '/template/admin.forum.remove.php'; 
	} elseif ($action == 'create') {
		require dirname(__FILE__) . '/template/admin.forum.create.php'; 
	} elseif ($action == 'edit') {
		require dirname(__FILE__) . '/template/admin.forum.edit.php'; 
	} else {
		require dirname(__FILE__) . '/template/admin.forum.php'; 
	}
}
